<?php

/** 
 * Candescent Widget Handler
 */
class CandescentWidgetHandler
{
	private bool $is_user_admin = false;
	private array $options = [];

	function __construct($candescent_options)
	{
		if (!empty($candescent_options) && is_array($candescent_options)) {
			$this->options = $candescent_options;
		}
	}

	public function init()
	{
		if (current_user_can('administrator')) {
			$this->is_user_admin = true;
		}
	}

	public function getOptions()
	{
		return $this->options;
	}

	public function render()
	{
		$class_string = ($this->is_user_admin) ? 'candescent admin' : 'candescent'; ?>
		<div class="<?= $class_string ?>">
			<?php $this->render_widget_toggle(); ?>
			<div class="candescent__options-container">
				<?php $this->render_widget_details(); ?>
				<hr />
				<div class="adjustment-container">
					<p>Accessibility Adjustments</p>
					<a href="javascript:;" class="adjustment-help" aria-label="learn more about the different accessibility adjustments">
						<svg width="22" height="22" viewBox="0 0 22 22" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M11 15V11M11 7H11.01M21 11C21 16.5228 16.5228 21 11 21C5.47715 21 1 16.5228 1 11C1 5.47715 5.47715 1 11 1C16.5228 1 21 5.47715 21 11Z" stroke="#16515e" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="transparent" />
						</svg>
					</a>
				</div>
				<?php $this->render_public_buttons() ?>
				<hr />
				<?php if ($this->is_user_admin) { ?>
					<div class="accessibility-container">
						<p>Accessibility Checker</p>
						<a href="javascript:;" class="accessibility-help" aria-label="learn more about the different accessibility checkers">
							<svg width="22" height="22" viewBox="0 0 22 22" fill="none" xmlns="http://www.w3.org/2000/svg">
								<path d="M11 15V11M11 7H11.01M21 11C21 16.5228 16.5228 21 11 21C5.47715 21 1 16.5228 1 11C1 5.47715 5.47715 1 11 1C16.5228 1 21 5.47715 21 11Z" stroke="#16515e" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" fill="transparent" />
							</svg>
						</a>
					</div>
					<?php $this->render_admin_buttons() ?>
					<hr />
				<?php } ?>
				<button class="candescent__widget-button candescent__widget-button--close candescent__close">Close</button>
			</div>
			<?php $this->render_notice() ?>
			<div class="candescent__notices hidden" style="display: none;">
			<?php $this->render_notice_data() ?>
			<?php $this->render_help_data() ?>
			</div>
		</div>
	<?php }

	private function render_widget_toggle()
	{
		require CANDESCENT_BUILD_PATH . "display/widget-toggle.php";
	}

	private function render_widget_details()
	{
		require CANDESCENT_BUILD_PATH . "display/widget-details.php";
	}

	private function render_public_buttons()
	{
		foreach ($this->options as $option) {
			if ($option['permission'] !== 'public') {
				continue;
			}
			$this->render_button($option);
		}
	}

	private function render_admin_buttons()
	{
		foreach ($this->options as $option) {
			if ($option['permission'] !== 'admin') {
				continue;
			}
			$this->render_button($option);
		}
	}

	private function render_button($option)
	{ $values = explode(",", $option['values'], 2);
		$value = $values[0];?>
		<button class="candescent__widget-button candescent__<?= $option['slug'] ?>"  aria-label="<?= $option['aria'] ?>"
			data-function="<?= $option['function'] ?>" data-type="<?= $option['type'] ?>" 
			data-name="<?= $option['name'] ?>" data-value="<?= $value ?>"
			data-values="<?= $option['values'] ?>" data-arias="<?= $option['arias'] ?>"
			data-preload="<?= $option['preload'] ?>">
			<span>
				<?= $option['icon'] ?>
			</span><?= $option['name'] ?>
		</button>
	<?php }

	private function render_notice()
	{
		require CANDESCENT_BUILD_PATH . "display/widget-notice.php";

	}

	private function render_notice_data()
	{
		foreach ($this->options as $option) {
			if ($option['type'] !== 'toggle-notice') {
				continue;
			} ?>
			<div class="candescent__notice_data" data-slug="<?=$option['slug']?>"><?php include CANDESCENT_BUILD_PATH . "notices/".$option['slug'].".php"; ?></div>
		<?php }
	}

	private function render_help_data()
	{
		$help_options = [
			[
				'slug' => 'adjustment-help',
			],
			[
				'slug' => 'admin-help',
			]
			];
		foreach ($help_options as $option) { ?>
			<div class="candescent__notice_data" data-slug="<?=$option['slug']?>"><?php include CANDESCENT_BUILD_PATH . "notices/".$option['slug'].".php"; ?></div>
		<?php }
	}
}
