<?php

/**
 * Plugin Name:     Candescent
 * Description:     Accessibility Guidance Tool
 * Version:         2.0.0
 * Author:          Ignition72
 * Author URI:		http://ignition72.com/
 * License:         GPL-2.0
 * Text Domain:     candescent
 *
 * @package         candescent
 */

 /**
  * Define Paths
  */
 define( 'CANDESCENT_BASE_PATH', plugin_dir_path( __FILE__ ) );
 define( 'CANDESCENT_BUILD_PATH', plugin_dir_path( __FILE__ ). "build/" );

 /**
  * Include candescent core and settings
  */
require_once CANDESCENT_BUILD_PATH . "core.php";
require_once CANDESCENT_BUILD_PATH . "settings.php";

 /**
  * Instantiate Candescent
  */
$CANDESCENT = new CandescentWidgetHandler($candescent_options);

/**
 * Register assets so that they can be enqueued in the corresponding context.
 */
add_action('init', function () use ($CANDESCENT)
{
	$dir = dirname(__FILE__);

	$script_asset_path = "$dir/build/index.asset.php";
	if (!file_exists($script_asset_path)) {
		throw new Error(
			'build/index.asset.php not Found. You need to run `npm install` and/or `npm run build` to compile the source first.'
		);
	}

	//Register the javascript.
	$index_js     = 'build/index.js';
	$script_asset = require($script_asset_path);
	wp_register_script(
		'candescent-script',
		plugins_url($index_js, __FILE__),
		$script_asset['dependencies'],
		$script_asset['version']
	);

	//Register the css.
	$editor_css = 'build/index.css';
	wp_register_style(
		'candescent-style',
		plugins_url($editor_css, __FILE__),
		array(),
		filemtime("$dir/$editor_css")
	);

	$CANDESCENT->init();
	
});


/**
 * Enqueue Scripts.
 */
function candescent_enqueue_scripts()
{
	if (!wp_script_is('jquery')) {
		wp_enqueue_script('jquery', 'https://code.jquery.com/jquery-3.6.0.min.js', false, false, true);
	}
	if (!wp_script_is('candescent-script')) {
		wp_enqueue_script('candescent-script');
	}
	if (!wp_style_is('candescent-style')) {
		wp_enqueue_style('candescent-style');
	}
}
add_action('wp_enqueue_scripts', 'candescent_enqueue_scripts');


/**
 * Render Candescent into header of page.
 */
add_action('wp_head', function () use ($CANDESCENT)
{
	$CANDESCENT->render();
});
