/**
 * Example JS module
 */

import * as functions from './functions';

export var CANDESCENT_CONTROLS = {
	init: function (candescentSettings) {
		CANDESCENT_CONTROLS.setWidgetToggle();
		CANDESCENT_CONTROLS.setInfoEvents();
		CANDESCENT_CONTROLS.preloadFunctions(candescentSettings);
		CANDESCENT_CONTROLS.setToggleEvents(candescentSettings);
		CANDESCENT_CONTROLS.setToggleNoticeEvents(candescentSettings);
	},
	setWidgetToggle: function () {
		jQuery('.candescent__toggle').on('click', function (event) {
			var toggleExpanded = (jQuery(event.currentTarget).attr('aria-expanded') == 'true') ? 'false' : 'true';

			jQuery('.candescent__toggle').attr('aria-expanded', toggleExpanded);
			jQuery('.candescent__options-container').toggleClass('active');
		});

		jQuery('.candescent__close').on('click', function () {
			jQuery('.candescent__toggle').attr('aria-expanded', false);
			jQuery('.candescent__options-container').removeClass('active');
		});

		var menu = jQuery('.candescent');
		// close accesibility menu when clicking elsewhere on page
		jQuery(document).on('click', function (event) {
			if (!menu.is(event.target) && menu.has(event.target).length === 0) {
				jQuery('.candescent__options-container').removeClass('active');
				jQuery('.candescent__notice').removeClass('active');
				jQuery('.candescent__notice-container').empty();
			}
		});
	},
	setInfoEvents: function () {
		jQuery('.adjustment-help').on('click', function(event) {
			var noticeContainer = jQuery('.candescent__notice-container');
			noticeContainer.empty();
			var notice = jQuery('.candescent__notice_data[data-slug="adjustment-help"]');
			if (notice) {
				noticeContainer.prepend(notice.html());
				jQuery('.candescent__notice').addClass('active');
				setTimeout(function () { jQuery('.candescent__notice-close').focus() }, 300);
			}
		});
	
	
		jQuery('.accessibility-help').on('click', function(event) {
			var noticeContainer = jQuery('.candescent__notice-container');
			noticeContainer.empty();
			var notice = jQuery('.candescent__notice_data[data-slug="admin-help"]');
			if (notice) {
				noticeContainer.prepend(notice.html());
				jQuery('.candescent__notice').addClass('active');
				setTimeout(function () { jQuery('.candescent__notice-close').focus() }, 300);
			}
		});
	
	},
	preloadFunctions: function (candescentSettings) {
		// contrast toggle button functionality
		jQuery('.candescent__widget-button[data-preload="true"]').each(function(index, element) {
			var button = jQuery(element);

			//Gather parts
			var value = button.attr('data-value');
			var values = button.attr('data-values');
			if (!values.startsWith(value)) {
				button.addClass('active');
			}
			var functionName = button.attr('data-function');		
			if (functionName && typeof functions[functionName] === 'function') {
				functions[functionName](value); // Execute the function
			} else {
				console.log(functionName+' is not a function or does not exist.');
			}
		});
	},
	setToggleEvents: function (candescentSettings) {
		// contrast toggle button functionality
		jQuery('.candescent__widget-button[data-type="toggle"]').on('click', function(event) {
			var button = jQuery(event.currentTarget);

			//Gather parts
			var functionName = button.attr('data-function');
			var value = button.attr('data-value');
			var values = button.attr('data-values');
			var aria = button.attr('aria-label');
			var arias = button.attr('data-arias');
			// Check if values is defined and not an empty string
			if (values && values.trim()&& arias && arias.trim()) {
				// Split the string by commas
				var valuesArray = values.split(',');
				var ariasArray = arias.split(',');
				if (valuesArray.length > 1 && value === valuesArray[0] && ariasArray.length > 1) {
					value = valuesArray[1];
					aria = ariasArray[1];
					button.addClass('active');
				} else {
					value = valuesArray[0];
					aria = ariasArray[0];
					button.removeClass('active');
				}
				button.attr('data-value',value);
				button.attr('aria-label', aria);
				candescentSettings.updateValue(functionName, value);
			
				if (functionName && typeof functions[functionName] === 'function') {
					functions[functionName](value); // Execute the function
				} else {
					console.log(functionName+' is not a function or does not exist.');
				}
			} else {
				// Handle the case where values is undefined or empty
				console.log(functionName+': No valid data-values found.');
			}
		});
	},
	setToggleNoticeEvents: function (candescentSettings) {
		// contrast toggle button functionality
		jQuery('.candescent__widget-button[data-type="toggle-notice"]').on('click', function(event) {
			var button = jQuery(event.currentTarget);
			var parent = jQuery(button.parent());
			var notice = jQuery(parent.siblings('.candescent__notice'));
			var noticeContainer = jQuery(notice.children('.candescent__notice-container'));

			//Gather parts
			var functionName = button.attr('data-function');
			var value = button.attr('data-value');
			var values = button.attr('data-values');
			var aria = button.attr('aria-label');
			var arias = button.attr('data-arias');
			// Check if values is defined and not an empty string
			if (values && values.trim()&& arias && arias.trim()) {
				// Split the string by commas
				var valuesArray = values.split(',');
				var ariasArray = arias.split(',');
				if (valuesArray.length > 1 && value === valuesArray[0] && ariasArray.length > 1) {
					value = valuesArray[1];
					aria = ariasArray[1];
					noticeContainer.empty();
					noticeContainer.append('<ul></ul>');
					button.addClass('active');
					parent.siblings('.candescent__notice').addClass('active');
					setTimeout(function () { jQuery('.candescent__notice-close').focus() }, 300);
				} else {
					value = valuesArray[0];
					aria = ariasArray[0];
					button.removeClass('active');
					parent.siblings('.candescent__notice').removeClass('active');
					parent.siblings('.candescent__notice').removeClass('none');
					noticeContainer.empty();		
				}
				button.attr('data-value',value);
				button.attr('aria-label', aria);
				candescentSettings.updateValue(functionName, value);

				if (functionName && typeof functions[functionName] === 'function') {
					functions[functionName](value, noticeContainer); // Execute the function
				} else {
					console.log(functionName+' is not a function or does not exist.');
				}

			} else {
				// Handle the case where values is undefined or empty
				console.log(functionName+': No valid data-values found.');
			}
		});

		jQuery('.candescent__notice-close').on('click', function(event) {
			var button = jQuery(event.currentTarget);
			var parent = jQuery(button.parent());
			var container = jQuery(parent.find('.candescent__notice-container'));

			parent.removeClass('active');
			container.empty();
		});
	},
}