/**
 * Example JS module
 */

export function contrastChecker(value, noticeContainer) {
	if (value === "on") {
		const RED = 0.2126;
		const GREEN = 0.7152;
		const BLUE = 0.0722;

		const GAMMA = 2.4;

		function luminance(r, g, b) {
			var a = [r, g, b].map((v) => {
				v /= 255;
				return v <= 0.03928
					? v / 12.92
					: Math.pow((v + 0.055) / 1.055, GAMMA);
			});
			return a[0] * RED + a[1] * GREEN + a[2] * BLUE;
		}

		function contrast(rgb1, rgb2) {
			var lum1 = luminance(...rgb1);
			var lum2 = luminance(...rgb2);
			var brightest = Math.max(lum1, lum2);
			var darkest = Math.min(lum1, lum2);
			return (brightest + 0.05) / (darkest + 0.05);
		}

		var total = 0;

		jQuery('body *').not('script, style, :hidden, #wpadminbar *').each(function (index, element) {
			var elem = jQuery(element),
				elemText = elem.clone().children().remove().end().text().replace(/[\t\n]+/g, ' ');

			if (!jQuery.trim(elemText).length == 0) {

				var textColor = elem.css('color'),
					bgColor = elem.css('backgroundColor'),
					textSize = elem.css('fontSize'),
					textSizeNum = textSize.slice(0, -2),
					textSizeVal = parseInt(textSizeNum),
					textWeight = elem.css('fontWeight');

				const textValues = textColor.replace(/\s/g, '').match(/\((.*)\)/)[1].split(',').map(Number);
				const bgValues = bgColor.replace(/\s/g, '').match(/\((.*)\)/)[1].split(',').map(Number);

				if (textValues.length == 4) {
					textValues.pop();
				}

				// check if background color exists on element. If not check parents until one is found
				if (elem.css('background-color').indexOf('rgba(0, 0, 0, 0)') == 0 || elem.css('background-color').indexOf('transparent') == 0) {

					var parents = elem.parents();
					parents.each(function (i, el) {

						if (jQuery(this).css('background-color').indexOf('rgba(0, 0, 0, 0)') == 0 || jQuery(this).css('background-color').indexOf('transparent') == 0) {
							//

						} else {
							if (jQuery(this).css('background-color')) {
								var bgColorValue = jQuery(this).css('backgroundColor').replace(/\s/g, '').match(/\((.*)\)/)[1].split(',').map(Number);
								bgColor = jQuery(this).css('backgroundColor');

								var contrastNum = contrast(textValues, bgColorValue);

								if (textSizeVal >= 24 || (textSizeVal >= 19 && textWeight == '700')) {
									if (contrastNum < 3) {
										elem.addClass('candescent__contrast-fail');
										total = total + 1;
										noticeContainer.children('ul').append(`<li class="ratio-help"><span><strong>Snippet:</strong> ${elem.text()}</span>Insufficient contrast ratio of <strong>${contrastNum.toFixed(2)}:1</strong>. Expected contrast ratio of <strong>3:1</strong><span class="color-f">Foreground color: <span style="background-color: ${textColor} !important"></span></span><span class="color-bg">Background color: <span style="background-color: ${bgColor} !important"></span></span></li>`);
									}
								} else {
									if (contrastNum < 4.5) {
										elem.addClass('candescent__contrast-fail');
										total = total + 1;
										noticeContainer.children('ul').append(`<li class="ratio-help"><span><strong>Snippet:</strong> ${elem.text()}</span>Insufficient contrast ratio of <strong>${contrastNum.toFixed(2)}:1</strong>. Expected contrast ratio of <strong>4.5:1</strong><span class="color-f">Foreground color: <span style="background-color: ${textColor} !important"></span></span><span class="color-bg">Background color: <span style="background-color: ${bgColor} !important"></span></span></li>`);
									}
								}

								return false;
							}

						}
					});
				} else {
					var contrastNum = contrast(textValues, bgValues);
					if (textSizeVal >= 24 || (textSizeVal >= 19 && textWeight == '700')) {
						if (contrastNum < 3) {
							elem.addClass('candescent__contrast-fail');
							total = total + 1;
							noticeContainer.children('ul').append(`<li class="ratio-help"><span><strong>Snippet:</strong> ${elem.text()}</span>Insufficient contrast ratio of <strong>${contrastNum.toFixed(2)}:1</strong>. Expected contrast ratio of <strong>3:1</strong><span class="color-f">Foreground color: <span style="background-color: ${textColor} !important"></span></span><span class="color-bg">Background color: <span style="background-color: ${bgColor} !important"></span></span></li>`);
						}
					} else {
						if (contrastNum < 4.5) {
							elem.addClass('candescent__contrast-fail');
							total = total + 1;
							noticeContainer.children('ul').append(`<li class="ratio-help"><span><strong>Snippet:</strong> ${elem.text()}</span>Insufficient contrast ratio of <strong>${contrastNum.toFixed(2)}:1</strong>. Expected contrast ratio of <strong>4.5:1</strong><span class="color-f">Foreground color: <span style="background-color: ${textColor} !important"></span></span><span class="color-bg">Background color: <span style="background-color: ${bgColor} !important"></span></span></li>`);
						}
					}
				}

			}

		});

		//Get Notice Content
		var notice = jQuery('.candescent__notice_data[data-slug="contrast-checker"]');
		if (notice) {
			var no_issue_content = notice.find('.no-issue');
			var with_issue_content = notice.find('.with-issue');
			with_issue_content.find('span.total-issues').html(total)
			var with_issue_prepend = with_issue_content.find('.prepend');
			var with_issue_append = with_issue_content.find('.append');
			if(total == 0) {
				noticeContainer.addClass('none').prepend(no_issue_content.html());
			} else {
				noticeContainer.removeClass('none').prepend(with_issue_prepend.html());
				noticeContainer.append(with_issue_append.html())
			}

		}

	} else {
		jQuery('.candescent__contrast-fail').removeClass('candescent__contrast-fail');
	}
}