/**
 * Example JS module
 */

//Internal only function.
function internalFunction() {
	var candescent = jQuery('.candescent');
	console.log(candescent);
}

//Example function.
export function toggleWidget() {
	jQuery('.candescent__toggle').on('click', function(event) {
		var toggleExpanded = (jQuery(event.currentTarget).attr('aria-expanded') == 'true') ? 'false' : 'true';

		jQuery('.candescent__toggle').attr('aria-expanded', toggleExpanded);
		jQuery('.candescent__options-container').toggleClass('active');
	});

	jQuery('.candescent__close').on('click', function() {
		jQuery('.candescent__toggle').attr('aria-expanded', false);
		jQuery('.candescent__options-container').removeClass('active');
	});

	var menu = jQuery('.candescent');
		// close accesibility menu when clicking elsewhere on page
		jQuery(document).on('click', function (event) {
			if (!menu.is(event.target) && menu.has(event.target).length === 0) {
				jQuery('.candescent__options-container').removeClass('active');
				jQuery('.candescent__image-details, .candescent__image-checker').removeClass('active');
				jQuery('.candescent__contrast-details, .candescent__contrast-checker').removeClass('active');
				jQuery('.candescent__link-details, .candescent__link-checker').removeClass('active');
				jQuery('.candescent__duplicate-details, .candescent__duplicate-checker').removeClass('active');
				jQuery('.candescent__adjustments-help, .candescent__checker-help').removeClass('active');
				jQuery('.candescent__contrast-details-container').empty();
				jQuery('.candescent__image-details-container').empty();
				jQuery('.candescent__link-details-container').empty();
				jQuery('.candescent__duplicate-details-container').empty();
			}
		});
}

//Second example function.
export function widgetFunctionality() {


	//If no local storage yet, check if user is already using browser dark mode
	function getSetting({ localStorageTheme, systemSettingDark }) {
		if (localStorageTheme !== null) {
			return localStorageTheme;
		}
	
		if (systemSettingDark.matches) {
			return "dark";
		}
	
		return "light";
	}

	// get zoom setting
	function getZoomSetting({ localStorageZoom}) {
		if (localStorageZoom !== null) {
			return localStorageZoom;
		}
	
		return "small";
	}

	// get focus setting
	function getFocusSetting({ localStorageFocus}) {
		if (localStorageFocus !== null) {
			return localStorageFocus;
		}
	
		return "no";
	}

	// get highlight setting
	function getHighlightSetting({ localStorageHighlight}) {
		if (localStorageHighlight !== null) {
			return localStorageHighlight;
		}
	
		return "no";
	}

	// update data attributes on page load to show appropriate styles
	function updateThemeOnHtml({ theme }) {
		jQuery("html").attr("data-theme", theme);
	}

	function updateZoomOnHtml({ zoom }) {
		jQuery("html").attr("data-zoom", zoom);
	}

	function updateFocusOnHtml({ focus }) {
		jQuery("html").attr("data-focus", focus);
	}

	function updateHighlightOnHtml({ highlight }) {
		jQuery("html").attr("data-highlight", highlight);
	}

	const localStorageTheme = localStorage.getItem("theme");
	const localStorageZoom = localStorage.getItem("zoom");
	const localStorageFocus = localStorage.getItem("focus");
	const localStorageHighlight = localStorage.getItem("highlight");
	const systemSettingDark = window.matchMedia("(prefers-color-scheme: dark)");

	var currentThemeSetting = getSetting({ localStorageTheme, systemSettingDark });
	var currentZoomSetting = getZoomSetting({ localStorageZoom });
	var currentFocusSetting = getFocusSetting({ localStorageFocus });
	var currentHighlightSetting = getHighlightSetting({ localStorageHighlight });

	updateThemeOnHtml({ theme: currentThemeSetting });
	updateZoomOnHtml({ zoom: currentZoomSetting });
	updateFocusOnHtml({ focus: currentFocusSetting });
	updateHighlightOnHtml({ highlight: currentHighlightSetting });

	//update contrast button aria-label on page load
	if (currentThemeSetting == 'dark') {
		jQuery('.candescent__contrast-toggle').attr('aria-label', 'Change to light theme');
		jQuery('.candescent__contrast-toggle').addClass('active');
	} else {
		jQuery('.candescent__contrast-toggle').attr('aria-label', 'Change to dark theme');
		jQuery('.candescent__contrast-toggle').removeClass('active');
	}

	//update zoom button aria-label on page load
	if (currentZoomSetting == 'large') {
		jQuery('.candescent__size-toggle').attr('aria-label', 'Decrease page zoom');
		jQuery('.candescent__size-toggle').addClass('active');
	} else {
		jQuery('.candescent__size-toggle').attr('aria-label', 'Increase page zoom');
		jQuery('.candescent__size-toggle').removeClass('active');
	}

	//update highlight button aria-label on page load
	if (currentFocusSetting == 'yes') {
		jQuery('.candescent__focus-toggle').attr('aria-label', 'Remove custom focus states when navigating with keyboard');
		jQuery('.candescent__focus-toggle').addClass('active');
	} else {
		jQuery('.candescent__focus-toggle').attr('aria-label', 'Add custom focus states when navigating with keyboard');
		jQuery('.candescent__focus-toggle').removeClass('active');
	}

	//update highlight button aria-label on page load
	if (currentHighlightSetting == 'yes') {
		jQuery('.candescent__link-toggle').attr('aria-label', 'Remove highlights from links');
		jQuery('.candescent__link-toggle').addClass('active');
	} else {
		jQuery('.candescent__link-toggle').attr('aria-label', 'Highlight links');
		jQuery('.candescent__link-toggle').removeClass('active');
	}

	// contrast toggle button functionality
	jQuery('.candescent__contrast-toggle').on('click', function(event) {
		var toggleTheme = (jQuery(event.currentTarget).attr('aria-label') == 'Change to dark theme') ? 'Change to light theme' : 'Change to dark theme';

		const newTheme = currentThemeSetting === "dark" ? "light" : "dark";

		localStorage.setItem("theme", newTheme);
		updateThemeOnHtml({ theme: newTheme });
	
		currentThemeSetting = newTheme;

		jQuery('.candescent__contrast-toggle').attr('aria-label', toggleTheme);
		jQuery('.candescent__contrast-toggle').toggleClass('active');
	});

	// zoom toggle button functionality
	jQuery('.candescent__size-toggle').on('click', function() {
		var toggleZoom = (jQuery('.candescent__size-toggle').attr('aria-label') == 'Increase page zoom') ? 'Decrease page zoom' : 'Increase page zoom';

		const newZoom = currentZoomSetting === "large" ? "small" : "large";

		localStorage.setItem("zoom", newZoom);
		updateZoomOnHtml({ zoom: newZoom });
	
		currentZoomSetting = newZoom;

		jQuery('.candescent__size-toggle').attr('aria-label', toggleZoom);
		jQuery('.candescent__size-toggle').toggleClass('active');

	});

	// focus state toggle button functionality
	jQuery('.candescent__focus-toggle').on('click', function() {
		var toggleFocus = (jQuery('.candescent__focus-toggle').attr('aria-label') == 'Add custom focus states when navigating with keyboard') ? 'Remove custom focus states when navigating with keyboard' : 'Add custom focus states when navigating with keyboard';

		const newFocus = currentFocusSetting === "yes" ? "no" : "yes";

		localStorage.setItem("focus", newFocus);
		updateFocusOnHtml({ focus: newFocus });
	
		currentFocusSetting = newFocus;

		jQuery('.candescent__focus-toggle').attr('aria-label', toggleFocus);
		jQuery('.candescent__focus-toggle').toggleClass('active');
	});

	// highlight link button functionality
	jQuery('.candescent__link-toggle').on('click', function() {
		var toggleLink = (jQuery('.candescent__link-toggle').attr('aria-label') == 'Highlight links') ? 'Remove highlights from links' : 'Highlight links';

		const newHighlight = currentHighlightSetting === "yes" ? "no" : "yes";

		localStorage.setItem("highlight", newHighlight);
		updateHighlightOnHtml({ highlight: newHighlight });
	
		currentHighlightSetting = newHighlight;

		jQuery('.candescent__link-toggle').attr('aria-label', toggleLink);
		jQuery('.candescent__link-toggle').toggleClass('active');
	});

}

export function imageChecker() {
	jQuery('.candescent__image-checker').on('click', function() {

		jQuery('.candescent__image-checker').toggleClass('active');

		if (!jQuery('.candescent__image-checker').hasClass('active')) {
			jQuery('.candescent__image-details').removeClass('active');
			jQuery('.candescent__image-details-container').empty();
			return;
		} else {
			var total = 0,
				totalIssues = 0;
			jQuery('.candescent__duplicate-details, .candescent__duplicate-checker, .candescent__contrast-details, .candescent__contrast-checker, .candescent__link-details, .candescent__link-checker').removeClass('active');
			jQuery('.candescent__adjustments-help, .candescent__checker-help').removeClass('active');
			jQuery('.candescent__contrast-details-container, .candescent__link-details-container, .candescent__duplicate-details-container').empty();
			jQuery('.candescent__image-details-container').append('<ul></ul>');

			jQuery('img, [role="img"]').not(':hidden, #wpadminbar img').each(function(index, element) {
				var image = jQuery(element),
					imageAlt = image.attr('alt'),
					imageTitle = image.attr('title'),
					imageLabel = image.attr('aria-label');
					
				if((!imageAlt) || (imageAlt == '')) {
					if((!imageTitle) || (imageTitle == '')) {
						if((!imageLabel) || (imageLabel == '')) {
							totalIssues = totalIssues+1;
							image.addClass('missing-alt');
							
							jQuery('.candescent__image-details-container ul').append(`<li><span class="img-error" style="background-image:url(${image[0].currentSrc})"></span></li>`);
						}
					}
				}
				total = total+1;
			});
			jQuery('.candescent__image-details').toggleClass('active');
			setTimeout(function () { jQuery('.candescent__image-details-close').focus() }, 300);
			if(total == 0) {
				jQuery('.candescent__image-details-container').addClass('none').prepend('<p>There are no images on this page</p>');
				return
			}

			if(totalIssues != 0) {
				jQuery('.candescent__image-details-container').removeClass('none').prepend(`<p>There are <span class="total-issues">${totalIssues}</span> images on this page that are missing descriptive alts. Images with missing alts can be seen outlined in a <span class="thick-solid">thick, solid red border.</span></p>`);
				jQuery('.candescent__image-details-container').append('<p>For more information about image alternative text click <a href="https://www.wcag.com/blog/good-alt-text-bad-alt-text-making-your-content-perceivable/" target="_blank" aria-label="visit WCAG website to learn more about alternative text">here</a>')
			} else {
				jQuery('.candescent__image-details-container').addClass('none').prepend('<p>Nice work! All images have descriptive alt text</p>');
			}
		}
	});

	jQuery('.candescent__image-details-close').on('click', function() {
		jQuery('.candescent__image-details').removeClass('active');
		jQuery('.candescent__image-checker').removeClass('active');
		jQuery('.candescent__image-details-container').empty();
		setTimeout(function () { jQuery('.candescent__image-checker').focus() }, 300);
	});
}

export function contrastChecker() {
	jQuery('.candescent__contrast-checker').on('click', function() {

		jQuery('.candescent__contrast-checker').toggleClass('active');

		if (!jQuery('.candescent__contrast-checker').hasClass('active')) {
			jQuery('.candescent__contrast-details').removeClass('active');
			jQuery('.candescent__contrast-details-container').empty();
			return;
		} else {
			jQuery('.candescent__duplicate-details, .candescent__duplicate-checker, .candescent__image-details, .candescent__image-checker, .candescent__link-details, .candescent__link-checker').removeClass('active');
			jQuery('.candescent__adjustments-help, .candescent__checker-help').removeClass('active');
			jQuery('.candescent__image-details-container, .candescent__link-details-container, .candescent__duplicate-details-container').empty();
			jQuery('.candescent__contrast-details-container').append('<ul></ul>');
			const RED = 0.2126;
			const GREEN = 0.7152;
			const BLUE = 0.0722;

			const GAMMA = 2.4;

			function luminance(r, g, b) {
				var a = [r, g, b].map((v) => {
					v /= 255;
					return v <= 0.03928
					? v / 12.92
					: Math.pow((v + 0.055) / 1.055, GAMMA);
			});
				return a[0] * RED + a[1] * GREEN + a[2] * BLUE;
			}

			function contrast(rgb1, rgb2) {
				var lum1 = luminance(...rgb1);
				var lum2 = luminance(...rgb2);
				var brightest = Math.max(lum1, lum2);
				var darkest = Math.min(lum1, lum2);
				return (brightest + 0.05) / (darkest + 0.05);
			}
			
			var total = 0;

			jQuery('body *').not('script, style, :hidden, #wpadminbar *').each(function(index, element) {
				var elem = jQuery(element),
					elemText = elem.clone().children().remove().end().text().replace(/[\t\n]+/g,' ');

				if(!jQuery.trim(elemText).length == 0) {
					
					var textColor = elem.css('color'),
						bgColor = elem.css('backgroundColor'),
						textSize = elem.css('fontSize'),
						textSizeNum = textSize.slice(0, -2),
						textSizeVal = parseInt(textSizeNum),
						textWeight = elem.css('fontWeight');

					const textValues = textColor.replace(/\s/g, '').match(/\((.*)\)/)[1].split(',').map(Number);
					const bgValues = bgColor.replace(/\s/g, '').match(/\((.*)\)/)[1].split(',').map(Number);

					if(textValues.length == 4) {
						textValues.pop();
					}
					
					// check if background color exists on element. If not check parents until one is found
					if(elem.css('background-color').indexOf('rgba(0, 0, 0, 0)') == 0 || elem.css('background-color').indexOf('transparent') == 0) {
						
						var parents = elem.parents();
						parents.each(function(i, el) {

							if( jQuery(this).css('background-color').indexOf('rgba(0, 0, 0, 0)') == 0 || jQuery(this).css('background-color').indexOf('transparent') == 0 ) {
								//
						
							} else {
								if( jQuery(this).css('background-color')) {
									var bgColorValue = jQuery(this).css('backgroundColor').replace(/\s/g, '').match(/\((.*)\)/)[1].split(',').map(Number);
									bgColor = jQuery(this).css('backgroundColor');
								
									var contrastNum = contrast(textValues, bgColorValue);

									if (textSizeVal >= 24 || (textSizeVal >= 19 && textWeight == '700')) {
										if (contrastNum < 3) {
											elem.addClass('contrast-fail');
											total = total+1;
											jQuery('.candescent__contrast-details ul').append(`<li class="ratio-help"><span><strong>Snippet:</strong> ${elem.text()}</span>Insufficient contrast ratio of <strong>${contrastNum.toFixed(2)}:1</strong>. Expected contrast ratio of <strong>3:1</strong><span class="color-f">Foreground color: <span style="background-color: ${textColor} !important"></span></span><span class="color-bg">Background color: <span style="background-color: ${bgColor} !important"></span></span></li>`);
										} 
									} else {
										if (contrastNum < 4.5) {
											elem.addClass('contrast-fail');
											total = total+1;
											jQuery('.candescent__contrast-details ul').append(`<li class="ratio-help"><span><strong>Snippet:</strong> ${elem.text()}</span>Insufficient contrast ratio of <strong>${contrastNum.toFixed(2)}:1</strong>. Expected contrast ratio of <strong>4.5:1</strong><span class="color-f">Foreground color: <span style="background-color: ${textColor} !important"></span></span><span class="color-bg">Background color: <span style="background-color: ${bgColor} !important"></span></span></li>`);
										}
									}

									return false;
								}
							
							}
						});
					} else {
						var contrastNum = contrast(textValues, bgValues);
						if (textSizeVal >= 24 || (textSizeVal >= 19 && textWeight == '700')) {
							if (contrastNum < 3) {
								elem.addClass('contrast-fail');
								total = total+1;
								jQuery('.candescent__contrast-details ul').append(`<li class="ratio-help"><span><strong>Snippet:</strong> ${elem.text()}</span>Insufficient contrast ratio of <strong>${contrastNum.toFixed(2)}:1</strong>. Expected contrast ratio of <strong>3:1</strong><span class="color-f">Foreground color: <span style="background-color: ${textColor} !important"></span></span><span class="color-bg">Background color: <span style="background-color: ${bgColor} !important"></span></span></li>`);
							} 
						} else {
							if (contrastNum < 4.5) {
								elem.addClass('contrast-fail');
								total = total+1;
								jQuery('.candescent__contrast-details ul').append(`<li class="ratio-help"><span><strong>Snippet:</strong> ${elem.text()}</span>Insufficient contrast ratio of <strong>${contrastNum.toFixed(2)}:1</strong>. Expected contrast ratio of <strong>4.5:1</strong><span class="color-f">Foreground color: <span style="background-color: ${textColor} !important"></span></span><span class="color-bg">Background color: <span style="background-color: ${bgColor} !important"></span></span></li>`);
							}
						}
					}

				}
					
			});
			jQuery('.candescent__contrast-details').addClass('active');
			setTimeout(function () { jQuery('.candescent__contrast-details-close').focus() }, 300);
			if(total == 0) {
				jQuery('.candescent__contrast-details-container').addClass('none').prepend('<p>Nice work! There are no color contrast issues</p>');
				jQuery('.candescent__contrast-details-close').focus();
			} else {
				jQuery('.candescent__contrast-details-container').removeClass('none').prepend(`<p>There are <span>${total}</span> color contrast issues.  Issues can be seen outlined in a <span class="dash">dashed red border.</span> More details below:</p>`);
				jQuery('.candescent__contrast-details-container').append('<p class="contrast-links">You can read more about color contrast issues <a href="https://www.w3.org/WAI/WCAG21/Understanding/contrast-minimum.html" target="_blank" aria-label="visit the WCAG website">here</a>');
				jQuery('.candescent__contrast-details-container').append('<p class="contrast-links"><a href="https://webaim.org/resources/contrastchecker/" target="_blank" aria-label="color contrast checker">Color contrast checker</a>')
			}
		}

	});

	jQuery('.candescent__contrast-details-close').on('click', function() {
		jQuery('.candescent__contrast-details').removeClass('active');
		jQuery('.candescent__contrast-checker').removeClass('active');
		jQuery('.candescent__contrast-details-container').empty();
		setTimeout(function () { jQuery('.candescent__contrast-checker').focus() }, 300);
	});

}

export function linkChecker() {
	jQuery('.candescent__link-checker').on('click', function() {

		jQuery('.candescent__link-checker').toggleClass('active');

		if (!jQuery('.candescent__link-checker').hasClass('active')) {
			jQuery('.candescent__link-details').removeClass('active');
			jQuery('.candescent__link-details-container').empty();
			return;
		} else {
			var total = 0,
				totalIssues = 0;
			jQuery('.candescent__duplicate-details, .candescent__duplicate-checker, .candescent__image-details, .candescent__image-checker, .candescent__contrast-details, .candescent__contrast-checker').removeClass('active');
			jQuery('.candescent__adjustments-help, .candescent__checker-help').removeClass('active');
			jQuery('.candescent__image-details-container, .candescent__contrast-details-container, .candescent__duplicate-details-container').empty();
			jQuery('.candescent__link-details-container').append('<ul></ul>');

			jQuery('a, button').each(function(index, element) {
				var link = jQuery(element),
					linkAria = link.attr('aria-label'),
					linkTitle = link.attr('title'),
					linkText = link.text().replace(/[\t\n]+/g,' ');
			
				total = total+1;
				if(jQuery.trim(linkText).length === 0) {
					if(linkAria || linkTitle) {
						// has aria or title attribute
					} else if (link.children().length == 0) {
						totalIssues = totalIssues+1;
						var outerElemTop = link.parent().html();
						jQuery('.candescent__link-details ul').append(`<li class="link-help-${totalIssues}"></li>`);
						jQuery(`.link-help-${totalIssues}`).text(outerElemTop);
						link.addClass('link-fail');
					} else {
						var childText = 0,
							outerElem = '';
						link.find('*').each(function(i, el) {
							var linkChild = jQuery(el),
								linkChildText = linkChild.text().replace(/[\t\n]+/g,' ');
	
							if(jQuery.trim(linkChildText).length === 0) {
								outerElem = link.parent().html();
							} else {
								childText = childText + 1;
							}
							
						});

						if (childText == 0) {
							totalIssues = totalIssues+1;

							jQuery('.candescent__link-details ul').append(`<li class="link-help-${totalIssues}"></li>`);
							jQuery(`.link-help-${totalIssues}`).text(outerElem);
							link.addClass('link-fail');
						}
					}
				} else {
					// has text
				}
			});
			jQuery('.candescent__link-details').toggleClass('active');
			setTimeout(function () { jQuery('.candescent__link-details-close').focus() }, 300);

			if(total == 0) {
				jQuery('.candescent__link-details-container').addClass('none').prepend('<p>There are no links or buttons on this page</p>');
				return
			}

			if(totalIssues != 0) {
				jQuery('.candescent__link-details-container').removeClass('none').prepend(`<p>There are <span class="total-issues">${totalIssues}</span> links or buttons on this page that are missing text or aria-labels. Links and buttons with missing text and/or aria-labels can be seen outlined in a <span class="solid">solid red border.</span></p>`);
				jQuery('.candescent__link-details-container').append(`<p class="link-fix-details">Fix ONE of the following:</p><ul class="link-fix-list"><li>Element does not have text that is visible to screen readers</li><li>aria-label attribute does not exist or is empty</li><li>Element has no title attribute</li></ul>`)
				jQuery('.candescent__link-details-container').append('<p>For more information about accessible links and buttons click <a href="https://www.w3.org/WAI/WCAG21/Understanding/link-purpose-in-context.html" target="_blank" aria-label="visit WCAG website to learn more about link and button text">here</a>')
			} else {
				jQuery('.candescent__link-details-container').addClass('none').prepend('<p>Nice work! All links and buttons are accessible</p>');
			}
		}
	});

	jQuery('.candescent__link-details-close').on('click', function() {
		jQuery('.candescent__link-details').removeClass('active');
		jQuery('.candescent__link-checker').removeClass('active');
		jQuery('.candescent__link-details-container').empty();
		setTimeout(function () { jQuery('.candescent__link-checker').focus() }, 300);
	});
}

export function duplicateChecker() {
	jQuery('.candescent__duplicate-checker').on('click', function() {

		jQuery('.candescent__duplicate-checker').toggleClass('active');

		if (!jQuery('.candescent__duplicate-checker').hasClass('active')) {
			jQuery('.candescent__duplicate-details').removeClass('active');
			jQuery('.candescent__duplicate-details-container').empty();
			return;
		} else {
			var totalIssues = 0;
			jQuery('.candescent__image-details, .candescent__image-checker, .candescent__contrast-details, .candescent__contrast-checker, .candescent__link-details, .candescent__link-checker').removeClass('active');
			jQuery('.candescent__adjustments-help, .candescent__checker-help').removeClass('active');
			jQuery('.candescent__contrast-details-container, .candescent__link-details-container, .candescent__image-details-container').empty();
			jQuery('.candescent__duplicate-details-container').append('<ul></ul>');

			var seenIds = {};
			var duplicates = [];

			jQuery('*[id]').each(function(index, element) {
				var elem = jQuery(element),
					elemID = elem.attr('id');
			
				if ((seenIds[elemID]) && (jQuery.inArray(`${elemID}`, duplicates) == -1)) {
					duplicates.push(elemID);
					totalIssues = totalIssues+1;
					
					jQuery('.candescent__duplicate-details-container > ul').append(`<li class="duplicate-help-${totalIssues}"><strong>#${elemID}</strong> <ul></ul></li>`);

					var outerElem = '';

					jQuery(`[id="${elemID}"]`).each(function(index, el) {
						var eleID = jQuery(el);
						
						outerElem = eleID[0].outerHTML;
						jQuery(`.duplicate-help-${totalIssues} > ul`).append(`<li class="duplicate-child-${index}"></li>`);
						jQuery(`.duplicate-help-${totalIssues} .duplicate-child-${index}`).text(outerElem);

						eleID.addClass('duplicate-fail');
					})

				} else {
					seenIds[elemID] = true;
				}
				
			});

			jQuery('.candescent__duplicate-details').toggleClass('active');
			setTimeout(function () { jQuery('.candescent__duplicate-details-close').focus() }, 300);

			if(totalIssues != 0) {
				jQuery('.candescent__duplicate-details-container').removeClass('none').prepend(`<p>There are <span class="total-issues">${totalIssues}</span> duplicate IDs on this page. Elements with duplicate IDs can be seen outlined in a <span class="dotted">dotted red border.</span></p>`);
				jQuery('.candescent__duplicate-details-container').append('<p>For more information about duplicate IDs click <a href="https://www.w3.org/WAI/WCAG21/Techniques/failures/F77" target="_blank" aria-label="visit WCAG website to learn more about duplicate IDs">here</a>')
			} else {
				jQuery('.candescent__duplicate-details-container').addClass('none').prepend('<p>Nice work! There are no duplicate IDs on this page.</p>');
			}
		}
	});

	jQuery('.candescent__duplicate-details-close').on('click', function() {
		jQuery('.candescent__duplicate-details').removeClass('active');
		jQuery('.candescent__duplicate-checker').removeClass('active');
		jQuery('.candescent__duplicate-details-container').empty();
		setTimeout(function () { jQuery('.candescent__duplicate-checker').focus() }, 300);
	});
}

export function helpToggle() {
	jQuery('.adjustment-help').on('click', function(event) {
		jQuery('.candescent__adjustments-help').toggleClass('active');
		jQuery('.candescent__checker-help').removeClass('active');
		jQuery('.candescent__duplicate-details, .candescent__duplicate-checker, .candescent__image-details, .candescent__image-checker, .candescent__contrast-details, .candescent__contrast-checker, .candescent__link-details, .candescent__link-checker').removeClass('active');
		jQuery('.candescent__contrast-details-container, .candescent__link-details-container, .candescent__image-details-container,.candescent__duplicate-details-container').empty();
		setTimeout(function () { jQuery('.candescent__adjustments-help-close').focus() }, 300);
	});

	jQuery('.candescent__adjustments-help-close').on('click', function() {
		jQuery('.candescent__adjustments-help').removeClass('active');
		setTimeout(function () { jQuery('.adjustment-help').focus() }, 300);
	});

	jQuery('.accessibility-help').on('click', function(event) {
		jQuery('.candescent__checker-help').toggleClass('active');
		jQuery('.candescent__adjustments-help').removeClass('active');
		jQuery('.candescent__duplicate-details, .candescent__duplicate-checker, .candescent__image-details, .candescent__image-checker, .candescent__contrast-details, .candescent__contrast-checker, .candescent__link-details, .candescent__link-checker').removeClass('active');
		jQuery('.candescent__contrast-details-container, .candescent__link-details-container, .candescent__image-details-container,.candescent__duplicate-details-container').empty();
		setTimeout(function () { jQuery('.candescent__checker-help-close').focus() }, 300);
	});

	jQuery('.candescent__checker-help-close').on('click', function() {
		jQuery('.candescent__checker-help').removeClass('active');
		setTimeout(function () { jQuery('.accessibility-help').focus() }, 300);
	});
}


// Alternatively you can skip the 'export's above, and just include the functions you want in the following snippet:
// export { exampleFunction, otherExampleFunction };